@@ -1,4 +1,4 @@
-SECRET_KEY = "Thanks for using django-bootstrap5!"
+SECRET_KEY = "Thanks for using django-bootstrap-v5!"
 
 DATABASES = {"default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}}
 
@@ -12,7 +12,7 @@ INSTALLED_APPS = (
     "django.contrib.staticfiles",
     "django.contrib.gis",
     # Our tests
-    "django_bootstrap5",
+    "bootstrap5",
     "tests",
 )
 
@@ -46,8 +46,9 @@ TEMPLATES = [
 ]
 
 BOOTSTRAP5 = {
+    "theme_url": "//example.com/theme.css",
     "javascript_in_head": True,
-    "required_css_class": "django_bootstrap5-req",
-    "error_css_class": "django_bootstrap5-err",
-    "success_css_class": "django_bootstrap5-bound",
+    "required_css_class": "bootstrap5-req",
+    "error_css_class": "bootstrap5-err",
+    "success_css_class": "bootstrap5-bound",
 }
